@@ -1,8 +1,10 @@
+from typing import Dict, Any
+
 from .get_uid_by_id import get_uid_by_id
 from ._requests_utils import *  # imports requests_get, requests_post, etc.
 from ._config import get_base_url
 
-def get_dataset_metadata(dataset_id: str = None, dataset_uid: str = None) -> str:
+def get_dataset_metadata(dataset_id: str = None, dataset_uid: str = None) -> Dict[str, Any]:
 
     if dataset_id is not None and dataset_uid is not None:
         exit(f"Error: dataset_id ({dataset_id}) and dataset_uid ({dataset_uid}) can't both be specified.")
